@@ -470,242 +470,6 @@ class PrimerSearchCommandline(_EmbossCommandLine):
         _EmbossCommandLine.__init__(self, cmd, **kwargs)
 
 
-class EProtDistCommandline(_EmbossCommandLine):
-    """Commandline object for the eprotdist program from EMBOSS (DEPRECATED).
-
-    This is an EMBOSS wrapper around protdist from PHYLIP.
-
-    It has been replaced by "fprotdist", see FProtDistCommandline.
-    """
-    def __init__(self, cmd="eprotdist", **kwargs):
-        import warnings
-        import Bio
-        warnings.warn("Bio.Emboss.Application.EProtDistCommandline has been deprecated; please use 'fprotdist' instead (see FProtDistCommandline).", Bio.BiopythonDeprecationWarning)
-        self.parameters = [
-          _Option(["-msf","msf"],
-                  "File containing sequences",
-                  is_required=True),
-          _Option(["-method","method"],
-                  "Choose the method to use",
-                  is_required=True),
-          _Option(["-categ","categ"],
-                  "Choose the category to use"),
-          _Option(["-gencode","gencode"],
-                  "Which genetic code"),
-          _Option(["-prob","prob"],
-                  "Prob change category (1.0=easy)"),
-          _Option(["-tranrate","tranrate"],
-                  "Transition/transversion ratio"),
-          _Option(["-freqa","freqa"],
-                  "Frequency for A"),
-          _Option(["-freqc","freqc"],
-                  "Frequency for C"),
-          _Option(["-freqg","freqg"],
-                  "Frequency for G"),
-          _Option(["-freqt","freqt"],
-                  "Frequency for T"),
-          _Option(["-printdata","printdata"],
-                  "Print out the data at start of run"),
-          _Option(["-progress","progress"],
-                  "Print indications of progress of run"),
-          _Option(["-basefrequency","basefrequency"],
-                  "Use empirical base frequencies")]
-        _EmbossCommandLine.__init__(self, cmd, **kwargs)
-
-
-class ENeighborCommandline(_EmbossCommandLine):
-    """Commandline object for the eneighbor program from EMBOSS (DEPRECATED).
-
-    This is an EMBOSS wrapper around neighbor from PHYLIP.
-
-    It has been replaced by "fneighbor", see FNeighborCommandline.
-    """
-    def __init__(self, cmd="eneighbor", **kwargs):
-        import warnings
-        import Bio
-        warnings.warn("Bio.Emboss.Application.ENeighborCommandline has been deprecated; please use 'fneighbor' instead (see FNeighborCommandline).", Bio.BiopythonDeprecationWarning)
-        self.parameters = [
-          _Option(["-infile","infile"],
-                  "infile value",
-                  is_required=True),
-          _Option(["-trout","trout"],
-                  "Create a tree file",
-                  is_required=True),
-          _Option(["-treefile","treefile"],
-                  "Tree file name",
-                  is_required=True),
-          _Option(["-nj","nj"],
-                  "Neighbor-joining",
-                  is_required=True), #TODO - Check this
-          _Option(["-noog","noog"],
-                  "Outgroup root",
-                  is_required=True), #TODO - Check this
-          _Option(["-outgnum","outgnum"],
-                  "number of the outgroup"),
-          _Option(["-randseed","randseed"],
-                  "Random number seed (must be odd)"),
-          _Option(["-datasets","datasets"],
-                  "How many data sets"),
-          _Option(["-drawtree","drawtree"],
-                  "Draw tree"),
-          _Option(["-lt","lt"],
-                  "Lower-triangular data matrix"),
-          _Option(["-ut","ut"],
-                  "Upper-triangular data matrix"),
-          _Option(["-sr","sr"],
-                  "Subreplicates"),
-          _Option(["-random","random"],
-                  "Randomize input order of species"),
-          _Option(["-multsets","multsets"],
-                  "Analyze multiple data sets"),
-          _Option(["-printdata","printdata"],
-                  "Print out the data at start of run"),
-          _Option(["-progress","progress"],
-                  "Print indications of progress of run")]
-        _EmbossCommandLine.__init__(self, cmd, **kwargs)
-
-
-class EProtParsCommandline(_EmbossCommandLine):
-    """Commandline object for the eprotpars program from EMBOSS (DEPRECATED).
-
-    This is an EMBOSS wrapper around protpars from PHYLIP.
-
-    It has been replaced by "fprotpars", see FProtParsCommandline.
-    """
-    def __init__(self, cmd="eprotpars", **kwargs):
-        import warnings
-        import Bio
-        warnings.warn("Bio.Emboss.Application.EProtParsCommandline has been deprecated; please use 'fprotpars' instead (see FProtParsCommandline).", Bio.BiopythonDeprecationWarning)
-        self.parameters = [
-          _Option(["-msf","msf"],
-                  "Sequences file to be read in",
-                  filename=True,
-                  is_required=True),
-          _Option(["-besttree","besttree"],
-                  "Search for the best tree"),
-          _Option(["-random","random"],
-                  "Randomize input order of species"),
-          _Option(["-norandom","norandom"],
-                  "Do not randomize input order of species"),
-          _Option(["-randseed","randseed"],
-                  "Random number seed (must be odd)"),
-          _Option(["-randtimes","randtimes"],
-                  "How many times to randomize"),
-          _Option(["-og","og"],
-                  "Use an outgroup root"),
-          _Option(["-noog","noog"],
-                  "Do not use an outgroup root"),
-          _Option(["-outgnum","outgnum"],
-                  "Number of the outgroup"),
-          _Option(["-thresh","thresh"],
-                  "Use Threshold parsimony"),
-          _Option(["-valthresh","valthresh"],
-                  "threshold value"),
-          _Option(["-printdata","printdata"],
-                  "Print out the data at start of run"),
-          _Option(["-progress","progress"],
-                  "Print indications of progress of run"),
-          _Option(["-steps","steps"],
-                  "Print out steps in each site"),
-          _Option(["-seqatnodes","seqatnodes"],
-                  "Print sequences at all nodes of tree"),
-          _Option(["-drawtree","drawtree"],
-                  "Draw tree"),
-          _Option(["-trout","trout"],
-                  "Create a tree file"),
-          _Option(["-notrout","notrout"],
-                  "Do not create a tree file"),
-          _Option(["-treefile","treefile"],
-                  "Output treefile name",
-                  types=["file"])]
-        _EmbossCommandLine.__init__(self, cmd, **kwargs)
-
-
-class EConsenseCommandline(_EmbossCommandLine):
-    """Commandline object for the econsense program from EMBOSS (DEPRECATED).
-
-    This is an EMBOSS wrapper around consense from PHYLIP.
-
-    It has been replaced by "fconsense", see FConsenseCommandline.
-    """
-    def __init__(self, cmd="econsense", **kwargs):
-        import warnings
-        import Bio
-        warnings.warn("Bio.Emboss.Application.EConsenseCommandline has been deprecated; please use 'fconsense' instead (see FConsenseCommandline).", Bio.BiopythonDeprecationWarning)
-        self.parameters = [
-          _Option(["-infile","infile"],
-                  "file to read in (New Hampshire standard form)",
-                  filename=True,
-                  is_required=True),
-          _Option(["-notrout","notrout"],
-                  "Do not create a tree file"),
-          _Option(["-trout","trout"],
-                  "Create a tree file"),
-          _Option(["-treefile","treefile"],
-                  "tree file name",
-                  filename=True),
-          _Option(["-noog","noog"],
-                  "Do not use an outgroup"),
-          _Option(["-og","og"],
-                  "Use an outgroup"),
-          _Option(["-outgnum","outgnum"],
-                  "number of the outgroup"),
-          _Option(["-nodrawtree","nodrawtree"],
-                  "Do not draw a tree"),
-          _Option(["-drawtree","drawtree"],
-                  "Draw tree"),
-          _Option(["-root","root"],
-                  "Trees to be treated as Rooted"),
-          _Option(["-progress","progress"],
-                  "Print indications of the progress of run"),
-          _Option(["-noprintsets","noprintsets"],
-                  "Do not print out the sets of species"),
-          _Option(["-printsets","printsets"],
-                  "Print out the sets of species")]
-        _EmbossCommandLine.__init__(self, cmd, **kwargs)
-
-
-class ESeqBootCommandline(_EmbossCommandLine):
-    """Commandline object for the eseqboot program from EMBOSS (DEPRECATED).
-
-    This is an EMBOSS wrapper around seqboot from PHYLIP.
-
-    It has been replaced by "fseqboot", see FSeqBootCommandline.
-    """
-    def __init__(self, cmd="eseqboot", **kwargs):
-        import warnings
-        import Bio
-        warnings.warn("Bio.Emboss.Application.ESeqBootCommandline has been deprecated; please use 'fseqboot' instead (see FSeqBootCommandline).", Bio.BiopythonDeprecationWarning)
-        self.parameters = [
-          _Option(["-datafile","datafile"],
-                  "Input file",
-                  filename=True,
-                  is_required=True),
-          _Option(["-randseed","randseed"],
-                  "Random number seed (must be odd)",
-                  is_required=True),
-          _Option(["-method","method"],
-                  "Choose the method",
-                  is_required=True), #TODO - Options?
-          _Option(["-test","test"],
-                  "Choose test", #TODO - options?
-                  is_required=True),
-          _Option(["-reps","reps"],
-                  "How many replicates",
-                  is_required=True),
-          _Option(["-inter","inter"],
-                  "Interleaved input"),
-          _Option(["-enzymes","enzymes"],
-                  "Present in input file"),
-          _Option(["-all","all"],
-                  "All alleles present at each locus"),
-          _Option(["-printdata","printdata"],
-                  "Print out the data at start of run"),
-          _Option(["-progress","progress"],
-                  "Print indications of progress of run")]
-        _EmbossCommandLine.__init__(self, cmd, **kwargs)
-
-
 class FDNADistCommandline(_EmbossCommandLine):
     """Commandline object for the fdnadist program from EMBOSS.
 
