@@ -161,6 +161,10 @@ class DataHandler(object):
 
     def read(self, handle):
         """Set up the parser and let it parse the XML results"""
+        if hasattr(handle, "closed") and handle.closed:
+            #Should avoid a possible Segmentation Fault, see:
+            #http://bugs.python.org/issue4877
+            raise IOError("Can't parse a closed handle")
         try:
             self.parser.ParseFile(handle)
         except expat.ExpatError, e:
