@@ -3,13 +3,9 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.  
 
-from Numeric import sqrt, argmin, argmax, sum, power, concatenate, array, Float0
-import os
+"""Model class, used in Structure objects."""
 
-# My Stuff
-from Entity import Entity
-
-__doc__="Model class, used in Structure objects."
+from Bio.PDB.Entity import Entity
 
 
 class Model(Entity):
@@ -20,12 +16,18 @@ class Model(Entity):
     normally contain many different models. 
     """
 
-    def __init__(self, id):
+    def __init__(self, id, serial_num = None):
         """
         Arguments:
         o id - int
+        o serial_num - int
         """
         self.level="M"
+        if serial_num is None:
+            self.serial_num=id
+        else:
+            self.serial_num=serial_num
+
         Entity.__init__(self, id)
 
     # Private methods
