@@ -4,23 +4,23 @@
 # as part of this package.
 
 # get set abstraction for graph representation
-from Bio.Pathway.Rep.HashSet import *
 
+#TODO - Subclass graph?
 class MultiGraph(object):
     """A directed multigraph abstraction with labeled edges."""
 
     def __init__(self, nodes = []):
         """Initializes a new MultiGraph object."""
-        self.__adjacency_list = {}    # maps parent -> set of (child, label) pairs
+        self._adjacency_list = {}    # maps parent -> set of (child, label) pairs
         for n in nodes:
-            self.__adjacency_list[n] = HashSet()
-        self.__label_map = {}         # maps label -> set of (parent, child) pairs
+            self._adjacency_list[n] = set()
+        self._label_map = {}         # maps label -> set of (parent, child) pairs
 
     def __eq__(self, g):
         """Returns true if g is equal to this graph."""
         return isinstance(g, MultiGraph) and \
-               (self.__adjacency_list == g.__adjacency_list) and \
-               (self.__label_map == g.__label_map)
+               (self._adjacency_list == g._adjacency_list) and \
+               (self._label_map == g._label_map)
 
     def __ne__(self, g):
         """Returns true if g is not equal to this graph."""
@@ -29,18 +29,18 @@ class MultiGraph(object):
     def __repr__(self):
         """Returns an unique string representation of this graph."""
         s = "<MultiGraph: "
-        keys = sorted(self.__adjacency_list.keys())
+        keys = sorted(self._adjacency_list.keys())
         for key in keys:
-            values = sorted(self.__adjacency_list[key].list())
+            values = sorted(self._adjacency_list[key])
             s += "(" + repr(key) + ": " + ",".join(map(repr, values)) + ")" 
         return s + ">"
 
     def __str__(self):
         """Returns a concise string description of this graph."""
-        nodenum = len(self.__adjacency_list)
+        nodenum = len(self._adjacency_list)
         edgenum = reduce(lambda x,y: x+y,
-                         map(len, self.__adjacency_list.values()))
-        labelnum = len(self.__label_map)
+                         map(len, self._adjacency_list.values()))
+        labelnum = len(self._label_map)
         return "<MultiGraph: " + \
                str(nodenum) + " node(s), " + \
                str(edgenum) + " edge(s), " + \
@@ -48,83 +48,79 @@ class MultiGraph(object):
 
     def add_node(self, node):
         """Adds a node to this graph."""
-        if node not in self.__adjacency_list:
-            self.__adjacency_list[node] = HashSet()
+        if node not in self._adjacency_list:
+            self._adjacency_list[node] = set()
 
     def add_edge(self, source, to, label = None):
         """Adds an edge to this graph."""
-        if source not in self.__adjacency_list:
+        if source not in self._adjacency_list:
             raise ValueError("Unknown <from> node: " + str(source))
-        if to not in self.__adjacency_list:
+        if to not in self._adjacency_list:
             raise ValueError("Unknown <to> node: " + str(to))
         edge = (to, label)
-        self.__adjacency_list[source].add(edge)
-        if label not in self.__label_map:
-            self.__label_map[label] = HashSet()
-        self.__label_map[label].add((source,to))
+        self._adjacency_list[source].add(edge)
+        if label not in self._label_map:
+            self._label_map[label] = set()
+        self._label_map[label].add((source,to))
 
     def child_edges(self, parent):
         """Returns a list of (child, label) pairs for parent."""
-        if parent not in self.__adjacency_list:
+        if parent not in self._adjacency_list:
             raise ValueError("Unknown <parent> node: " + str(parent))
-        return self.__adjacency_list[parent].list()
+        return sorted(self._adjacency_list[parent])
 
     def children(self, parent):
         """Returns a list of unique children for parent."""
-        s = HashSet([x[0] for x in self.child_edges(parent)])
-        return s.list()
+        return sorted(set([x[0] for x in self.child_edges(parent)]))
 
     def edges(self, label):
         """Returns a list of all the edges with this label."""
-        if label not in self.__label_map:
+        if label not in self._label_map:
             raise ValueError("Unknown label: " + str(label))
-        return self.__label_map[label].list()
+        return sorted(self._label_map[label])
 
     def labels(self):
         """Returns a list of all the edge labels in this graph."""
-        return self.__label_map.keys()
+        return self._label_map.keys()
 
     def nodes(self):
         """Returns a list of the nodes in this graph."""
-        return self.__adjacency_list.keys()
+        return self._adjacency_list.keys()
 
     def parent_edges(self, child):
         """Returns a list of (parent, label) pairs for child."""
-        if child not in self.__adjacency_list:
+        if child not in self._adjacency_list:
             raise ValueError("Unknown <child> node: " + str(child))
         parents = []
-        for parent in self.__adjacency_list:
-            children = self.__adjacency_list[parent]
-            for x in children.list():
+        for parent, children in self._adjacency_list.iteritems():
+            for x in children:
                 if x[0] is child:
                     parents.append((parent, x[1]))
-        return parents
+        return sorted(parents)
 
     def parents(self, child):
         """Returns a list of unique parents for child."""
-        s = HashSet([x[0] for x in self.parent_edges(child)])
-        return s.list()
+        return sorted(set([x[0] for x in self.parent_edges(child)]))
 
     def remove_node(self, node):
         """Removes node and all edges connected to it."""
-        if node not in self.__adjacency_list:
+        if node not in self._adjacency_list:
             raise ValueError("Unknown node: " + str(node))
         # remove node (and all out-edges) from adjacency list
-        del self.__adjacency_list[node]
+        del self._adjacency_list[node]
         # remove all in-edges from adjacency list
-        for n in self.__adjacency_list:
-            self.__adjacency_list[n] = HashSet(filter(lambda x,node=node: x[0] is not node,
-                                                      self.__adjacency_list[n].list()))
+        for n in self._adjacency_list:
+            self._adjacency_list[n] = set(x for x in self._adjacency_list[n] \
+                                          if x[0] is not node)
         # remove all refering pairs in label map
-        for label in self.__label_map.keys():
-            lm = HashSet(filter(lambda x,node=node: \
-                                (x[0] is not node) and (x[1] is not node),
-                                self.__label_map[label].list()))
+        for label in self._label_map.keys():
+            lm = set(x for x in self._label_map[label] \
+                     if (x[0] is not node) and (x[1] is not node))
             # remove the entry completely if the label is now unused
-            if lm.empty():
-                del self.__label_map[label]
+            if lm:
+                self._label_map[label] = lm
             else:
-                self.__label_map[label] = lm
+                del self._label_map[label]
 
     def remove_edge(self, parent, child, label):
         """Removes edge. -- NOT IMPLEMENTED"""
