@@ -13,7 +13,7 @@ import re
 _pdbid_re = re.compile(r"^(\w\w\w\w)(?:$|\s+|_)(.*)")
 _fragment_re = re.compile(r"\(?(\w:)?(-?\w*)-?(-?\w*)\)?(.*)")
 
-class Residues:
+class Residues(object):
     """A collection of residues from a PDB structure.
 
     This class provides code to work with SCOP domain definitions. These
