@@ -1,4 +1,3 @@
-import string
 from Bio import Alphabet
 COUNT = 1
 FREQ = 2
@@ -50,18 +49,14 @@ FREQ = 2
 class FreqTable(dict):
     
     def _freq_from_count(self):
-        sum = 0.
-        for i in self.count.values():
-            sum = sum + i
-        for i in self.count.keys():
-            self[i] = self.count[i] / sum
+        total = float(sum(self.count.values()))
+        for i, v in self.count.iteritems():
+            self[i] = v / total
 
     def _alphabet_from_input(self):
         s = ''
-        letters_list = self.keys()
-        letters_list.sort()
-        for i in letters_list:
-            s = s + i
+        for i in sorted(self):
+            s += i
         return s
 
     def __init__(self,in_dict,dict_type,alphabet=None):
@@ -79,17 +74,17 @@ class FreqTable(dict):
             self.alphabet.letters = self._alphabet_from_input()
 
 def read_count(f):
-    l = map(string.split,map(string.strip,f.readlines()))
     count = {}
-    for i in l:
-        count[i[0]] = int(i[1])
+    for line in f:
+        key, value = line.strip().split()
+        count[key] = int(value)
     freq_table = FreqTable(count,COUNT)
     return freq_table
 
 def read_freq(f):
     freq_dict = {}
-    l = map(string.split,map(string.strip,f.readlines()))
-    for i in l:
-        freq_dict[i[0]] = float(i[1]) 
+    for line in f:
+        key, value = line.strip().split()
+        freq_dict[key] = float(value) 
     return FreqTable(freq_dict,FREQ)
 
