@@ -9,23 +9,21 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-import string, re
-import os, sys
+import re
+import sys
 import time
 
 from Tkinter import *
 from tkFileDialog import askopenfilename, asksaveasfilename
 
 sys.path.insert(0, '.')
-import xbb_io
 from xbb_utils import *
 from xbb_translations import xbb_translations
 from xbb_blast import BlastIt
 from xbb_search import XDNAsearch
 from xbb_help import xbbtools_help
-from Bio import Translate
-from Bio.sequtils import quick_FASTA_reader
-
+from Bio.Data import CodonTable
+from Bio.SeqUtils import quick_FASTA_reader
 
 
 class xbb_widget:
@@ -62,10 +60,9 @@ class xbb_widget:
         
     def init_variables(self):
         self.seqwidth = 60
-        self.seq_io = xbb_io.xbb_io()
         self.translation_tables = {}
-        for i in Translate.unambiguous_dna_by_id.keys():
-            self.translation_tables[Translate.unambiguous_dna_by_id[i].table.names[0]] = i
+        for i, table in CodonTable.unambiguous_dna_by_id.iteritems():
+            self.translation_tables[table.names[0]] = i
         self.translator = xbb_translations()
 
     def init_colors(self):
@@ -109,19 +106,19 @@ class xbb_widget:
         # how would one implement Tk's -class ?
         tk = self.main_frame.master
         for k,v in self.colorsbg.items():
-            name = '*' + string.upper(k[0]) + k[1:] + '.background'
+            name = '*' + k[0].upper() + k[1:] + '.background'
             tk.option_add(name, v)
 
         for k,v in self.colorsfg.items():
-            name = '*' + string.upper(k[0]) + k[1:] + '.foreground'
+            name = '*' + k[0].upper() + k[1:] + '.foreground'
             tk.option_add(name, v)
             
         for k,v in self.colorsPMWbg.items():
-            name = '*' + string.upper(k[0]) + k[1:] + '.background'
+            name = '*' + k[0].upper() + k[1:] + '.background'
             tk.option_add(name, v)
 
         for k,v in self.colorsPMWfg.items():
-            name = '*' + string.upper(k[0]) + k[1:] + '.foreground'
+            name = '*' + k[0].upper() + k[1:] + '.foreground'
             tk.option_add(name, v)
             
     def create_menu(self, parent):
@@ -313,8 +310,8 @@ class xbb_widget:
         w = self.sequence_id
         w.selection_own()
         try:
-            a = int(string.split(w.index('sel.first'), '.')[1]) +1
-            b = int(string.split(w.index('sel.last'), '.')[1])
+            a = int(w.index('sel.first').split('.')[1]) +1
+            b = int(w.index('sel.last').split('.')[1])
             length = b - a + 1
 
             self.position_ids['from_id'].configure(text = 'Start:%d'% a)
@@ -324,7 +321,7 @@ class xbb_widget:
             self.statistics_ids['length_id'].configure(text = 'Length=%d' % length)
             seq = self.get_self_selection()
             for nt in ['A','C','G','T']:
-                n = string.count(seq,nt)
+                n = seq.count(nt)
                 self.statistics_ids[nt].configure(text = '%s=%d' % (nt,n))
                 
             
@@ -334,7 +331,7 @@ class xbb_widget:
     def position(self, event):
         x = event.x
         y = event.y
-        pos = string.split(self.sequence_id.index('@%d,%d' % (x,y)),'.')
+        pos = self.sequence_id.index('@%d,%d' % (x,y)).split('.')
         pos = int(pos[1]) + 1
         self.position_ids['id'].configure(text = str(pos))
         
@@ -342,26 +339,25 @@ class xbb_widget:
         if not file:
             file = askopenfilename()
         if not file: return
-        #genes = self.seq_io.read_fasta_file(file)
         genes = quick_FASTA_reader(file)
         self.insert_sequence(genes[0])
 
     def insert_sequence(self, (name, sequence)):
         self.sequence_id.delete(0.0, END)
-        self.sequence_id.insert(END, string.upper(sequence))
+        self.sequence_id.insert(END, sequence.upper())
         self.fix_sequence()
         self.update_label(name)
 
     def fix_sequence(self):
         seq = self.sequence_id.get(1.0,END)
-        seq = string.upper(seq)
+        seq = seq.upper()
         seq = re.sub('[^A-Z]','',seq)
         self.sequence_id.delete(0.0,END)
         self.sequence_id.insert(END, seq)
         
     def update_label(self, header):
-        name = string.split(header,' ')[0]
-        name = string.split(name,',')[0]
+        name = header.split(' ')[0]
+        name = name.split(',')[0]
         self.position_ids['label'].configure(text = name)
         
     def export(self):
@@ -387,7 +383,7 @@ class xbb_widget:
         if not seq: return
         aa_seq = self.translator.frame(seq, frame, self.current_codon_table_id)
         print '>%s<' % aa_seq
-        aa_seq = re.sub('(.{50})','\\1\n',aa_seq.data)
+        aa_seq = re.sub('(.{50})','\\1\n',str(aa_seq))
         np = NotePad()
         tid = np.text_id()
         tid.insert(END,'>frame%d\n%s' % (frame,aa_seq))
@@ -395,7 +391,7 @@ class xbb_widget:
     def statistics(self):
         seq = self.get_selection_or_sequence()
         if not seq: return
-        seq = string.upper(seq)
+        seq = seq.upper()
         aa = {'A':0,'C':0,'G':0,'T':0,'N':0}
         for nt in seq:
             if nt not in aa: nt = 'N'
@@ -431,7 +427,7 @@ GC=%f
         seq = w.get(start, stop)
         seq = map(None,re.sub('[^A-Z]','',seq))
         seq.reverse()
-        seq = string.join(seq,'')
+        seq = ''.join(seq)
 
         w.delete(start, stop)
         w.insert(start, seq)
