@@ -37,7 +37,7 @@ test_files = [
 #Following example is also used in test_Nexus.py
     ("nexus", 9, 1, 'Nexus/test_Nexus_input.nex'),
     ("stockholm", 2, 1, 'Stockholm/simple.sth'),
-    ("stockholm", 5, 1, 'Stockholm/funny.sth'),
+    ("stockholm", 6, 1, 'Stockholm/funny.sth'),
     ("phylip", 6, 1, 'Phylip/reference_dna.phy'),
     ("phylip", 6, 1, 'Phylip/reference_dna2.phy'),
     ("phylip",10, 1, 'Phylip/hennigian.phy'),
@@ -46,6 +46,8 @@ test_files = [
     ("phylip", 3, 1, 'Phylip/interlaced.phy'),
     ("phylip", 4, 1, 'Phylip/interlaced2.phy'),
     ("phylip-relaxed", 12, 1, 'ExtendedPhylip/primates.phyx'),
+    ("phylip-sequential", 3, 1, 'Phylip/sequential.phy'),
+    ("phylip-sequential", 4, 1, 'Phylip/sequential2.phy'),
     ("emboss", 4, 1, 'Emboss/alignret.txt'),
     ("emboss", 2, 5, 'Emboss/needle.txt'),
     ("emboss", 2, 1, 'Emboss/needle_asis.txt'),
@@ -173,7 +175,7 @@ def simple_alignment_comparison(alignments, alignments2, format):
 
             #Beware of different quirks and limitations in the
             #valid character sets and the identifier lengths!
-            if format=="phylip":
+            if format in ["phylip", "phylip-sequential"]:
                 assert r1.id.replace("[","").replace("]","")[:10] == r2.id, \
                        "'%s' vs '%s'" % (r1.id, r2.id)
             elif format=="phylip-relaxed":
