@@ -30,20 +30,20 @@ class TestCluster(unittest.TestCase):
             from Pycluster import mean, median
 
         data = numpy.array([ 34.3, 3, 2 ])
-        self.assertAlmostEqual(mean(data), 13.1, 3)
-        self.assertAlmostEqual(median(data), 3.0, 3)
+        self.assertAlmostEqual(mean(data), 13.1, places=3)
+        self.assertAlmostEqual(median(data), 3.0, places=3)
 
         data = [ 5, 10, 15, 20]
-        self.assertAlmostEqual(mean(data), 12.5, 3)
-        self.assertAlmostEqual(median(data), 12.5, 3)
+        self.assertAlmostEqual(mean(data), 12.5, places=3)
+        self.assertAlmostEqual(median(data), 12.5, places=3)
 
         data = [ 1, 2, 3, 5, 7, 11, 13, 17]
-        self.assertAlmostEqual(mean(data), 7.375, 3)
-        self.assertAlmostEqual(median(data), 6.0, 3)
+        self.assertAlmostEqual(mean(data), 7.375, places=3)
+        self.assertAlmostEqual(median(data), 6.0, places=3)
 
         data = [ 100, 19, 3, 1.5, 1.4, 1, 1, 1]
-        self.assertAlmostEqual(mean(data), 15.988, 3)
-        self.assertAlmostEqual(median(data), 1.45, 3)
+        self.assertAlmostEqual(mean(data), 15.988, places=3)
+        self.assertAlmostEqual(median(data), 1.45, places=3)
       
 
     def test_matrix_parse(self):
@@ -206,15 +206,15 @@ class TestCluster(unittest.TestCase):
         distance = clusterdistance(data, mask=mask, weight=weight,
                                    index1=c1, index2=c2, dist='e',
                                    method='a', transpose=0);
-        self.assertAlmostEqual(distance, 6.650, 3)
+        self.assertAlmostEqual(distance, 6.650, places=3)
         distance = clusterdistance(data, mask=mask, weight=weight,
                                    index1=c1, index2=c3, dist='e',
                                    method='a', transpose=0);
-        self.assertAlmostEqual(distance, 32.508, 3)
+        self.assertAlmostEqual(distance, 32.508, places=3)
         distance = clusterdistance(data, mask=mask, weight=weight,
                                    index1=c2, index2=c3, dist='e',
                                    method='a', transpose=0);
-        self.assertAlmostEqual(distance, 15.118, 3)
+        self.assertAlmostEqual(distance, 15.118, places=3)
 
         # Second data set
         weight =  numpy.array([ 1,1 ])
@@ -253,15 +253,15 @@ class TestCluster(unittest.TestCase):
         distance = clusterdistance(data, mask=mask, weight=weight,
                                    index1=c1, index2=c2, dist='e',
                                    method='a', transpose=0);
-        self.assertAlmostEqual(distance, 5.833, 3)
+        self.assertAlmostEqual(distance, 5.833, places=3)
         distance = clusterdistance(data, mask=mask, weight=weight,
                                    index1=c1, index2=c3, dist='e',
                                    method='a', transpose=0);
-        self.assertAlmostEqual(distance, 3.298, 3)
+        self.assertAlmostEqual(distance, 3.298, places=3)
         distance = clusterdistance(data, mask=mask, weight=weight,
                                    index1=c2, index2=c3, dist='e',
                                    method='a', transpose=0);
-        self.assertAlmostEqual(distance, 0.360, 3)
+        self.assertAlmostEqual(distance, 0.360, places=3)
 
 
     def test_treecluster(self):
@@ -288,13 +288,13 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data1)-1)
         self.assertEqual(tree[0].left, 2)
         self.assertEqual(tree[0].right, 1)
-        self.assertAlmostEqual(tree[0].distance, 2.600, 3)
+        self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
         self.assertEqual(tree[1].left, -1)
         self.assertEqual(tree[1].right, 0)
-        self.assertAlmostEqual(tree[1].distance, 7.300, 3)
+        self.assertAlmostEqual(tree[1].distance, 7.300, places=3)
         self.assertEqual(tree[2].left, 3)
         self.assertEqual(tree[2].right, -2)
-        self.assertAlmostEqual(tree[2].distance, 21.348, 3)
+        self.assertAlmostEqual(tree[2].distance, 21.348, places=3)
 
         # Pairwise single-linkage clustering
         tree = treecluster(data=data1, mask=mask1, weight=weight1,
@@ -302,13 +302,13 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data1)-1)
         self.assertEqual(tree[0].left, 1)
         self.assertEqual(tree[0].right, 2)
-        self.assertAlmostEqual(tree[0].distance, 2.600, 3)
+        self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
         self.assertEqual(tree[1].left, 0)
         self.assertEqual(tree[1].right, -1)
-        self.assertAlmostEqual(tree[1].distance, 5.800, 3)
+        self.assertAlmostEqual(tree[1].distance, 5.800, places=3)
         self.assertEqual(tree[2].left, -2)
         self.assertEqual(tree[2].right, 3)
-        self.assertAlmostEqual(tree[2].distance, 12.908, 3)
+        self.assertAlmostEqual(tree[2].distance, 12.908, places=3)
 
         # Pairwise centroid-linkage clustering
         tree = treecluster(data=data1, mask=mask1, weight=weight1,
@@ -316,13 +316,13 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data1)-1)
         self.assertEqual(tree[0].left, 1)
         self.assertEqual(tree[0].right, 2)
-        self.assertAlmostEqual(tree[0].distance, 2.600, 3)
+        self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
         self.assertEqual(tree[1].left, 0)
         self.assertEqual(tree[1].right, -1)
-        self.assertAlmostEqual(tree[1].distance, 6.650, 3)
+        self.assertAlmostEqual(tree[1].distance, 6.650, places=3)
         self.assertEqual(tree[2].left, -2)
         self.assertEqual(tree[2].right, 3)
-        self.assertAlmostEqual(tree[2].distance, 19.437, 3)
+        self.assertAlmostEqual(tree[2].distance, 19.437, places=3)
 
         # Pairwise maximum-linkage clustering
         tree = treecluster(data=data1, mask=mask1, weight=weight1,
@@ -330,13 +330,13 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data1)-1)
         self.assertEqual(tree[0].left, 2)
         self.assertEqual(tree[0].right, 1)
-        self.assertAlmostEqual(tree[0].distance, 2.600, 3)
+        self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
         self.assertEqual(tree[1].left, -1)
         self.assertEqual(tree[1].right, 0)
-        self.assertAlmostEqual(tree[1].distance, 8.800, 3)
+        self.assertAlmostEqual(tree[1].distance, 8.800, places=3)
         self.assertEqual(tree[2].left, 3)
         self.assertEqual(tree[2].right, -2)
-        self.assertAlmostEqual(tree[2].distance, 32.508, 3)
+        self.assertAlmostEqual(tree[2].distance, 32.508, places=3)
       
         # Second data set
         weight2 =  [ 1,1 ]
@@ -374,40 +374,40 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data2)-1)
         self.assertEqual(tree[0].left, 5)
         self.assertEqual(tree[0].right, 4)
-        self.assertAlmostEqual(tree[0].distance, 0.003, 3)
+        self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
         self.assertEqual(tree[1].left, 9)
         self.assertEqual(tree[1].right, 12)
-        self.assertAlmostEqual(tree[1].distance, 0.029, 3)
+        self.assertAlmostEqual(tree[1].distance, 0.029, places=3)
         self.assertEqual(tree[2].left, 2)
         self.assertEqual(tree[2].right, 1)
-        self.assertAlmostEqual(tree[2].distance, 0.061, 3)
+        self.assertAlmostEqual(tree[2].distance, 0.061, places=3)
         self.assertEqual(tree[3].left, 11)
         self.assertEqual(tree[3].right, -2)
-        self.assertAlmostEqual(tree[3].distance, 0.070, 3)
+        self.assertAlmostEqual(tree[3].distance, 0.070, places=3)
         self.assertEqual(tree[4].left, -4)
         self.assertEqual(tree[4].right, 10)
-        self.assertAlmostEqual(tree[4].distance, 0.128, 3)
+        self.assertAlmostEqual(tree[4].distance, 0.128, places=3)
         self.assertEqual(tree[5].left, 7)
         self.assertEqual(tree[5].right, -5)
-        self.assertAlmostEqual(tree[5].distance, 0.224, 3)
+        self.assertAlmostEqual(tree[5].distance, 0.224, places=3)
         self.assertEqual(tree[6].left, -3)
         self.assertEqual(tree[6].right, 0)
-        self.assertAlmostEqual(tree[6].distance, 0.254, 3)
+        self.assertAlmostEqual(tree[6].distance, 0.254, places=3)
         self.assertEqual(tree[7].left, -1)
         self.assertEqual(tree[7].right, 3)
-        self.assertAlmostEqual(tree[7].distance, 0.391, 3)
+        self.assertAlmostEqual(tree[7].distance, 0.391, places=3)
         self.assertEqual(tree[8].left, -8)
         self.assertEqual(tree[8].right, -7)
-        self.assertAlmostEqual(tree[8].distance, 0.532, 3)
+        self.assertAlmostEqual(tree[8].distance, 0.532, places=3)
         self.assertEqual(tree[9].left, 8)
         self.assertEqual(tree[9].right, -9)
-        self.assertAlmostEqual(tree[9].distance, 3.234, 3)
+        self.assertAlmostEqual(tree[9].distance, 3.234, places=3)
         self.assertEqual(tree[10].left, -6)
         self.assertEqual(tree[10].right, 6)
-        self.assertAlmostEqual(tree[10].distance, 4.636, 3)
+        self.assertAlmostEqual(tree[10].distance, 4.636, places=3)
         self.assertEqual(tree[11].left, -11)
         self.assertEqual(tree[11].right, -10)
-        self.assertAlmostEqual(tree[11].distance, 12.741, 3)
+        self.assertAlmostEqual(tree[11].distance, 12.741, places=3)
       
         # Pairwise single-linkage clustering
         tree = treecluster(data=data2, mask=mask2, weight=weight2,
@@ -415,40 +415,40 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data2)-1)
         self.assertEqual(tree[0].left, 4)
         self.assertEqual(tree[0].right, 5)
-        self.assertAlmostEqual(tree[0].distance, 0.003, 3)
+        self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
         self.assertEqual(tree[1].left, 9)
         self.assertEqual(tree[1].right, 12)
-        self.assertAlmostEqual(tree[1].distance, 0.029, 3)
+        self.assertAlmostEqual(tree[1].distance, 0.029, places=3)
         self.assertEqual(tree[2].left, 11)
         self.assertEqual(tree[2].right, -2)
-        self.assertAlmostEqual(tree[2].distance, 0.033, 3)
+        self.assertAlmostEqual(tree[2].distance, 0.033, places=3)
         self.assertEqual(tree[3].left, 1)
         self.assertEqual(tree[3].right, 2)
-        self.assertAlmostEqual(tree[3].distance, 0.061, 3)
+        self.assertAlmostEqual(tree[3].distance, 0.061, places=3)
         self.assertEqual(tree[4].left, 10)
         self.assertEqual(tree[4].right, -3)
-        self.assertAlmostEqual(tree[4].distance, 0.077, 3)
+        self.assertAlmostEqual(tree[4].distance, 0.077, places=3)
         self.assertEqual(tree[5].left, 7)
         self.assertEqual(tree[5].right, -5)
-        self.assertAlmostEqual(tree[5].distance, 0.092, 3)
+        self.assertAlmostEqual(tree[5].distance, 0.092, places=3)
         self.assertEqual(tree[6].left, 0)
         self.assertEqual(tree[6].right, -4)
-        self.assertAlmostEqual(tree[6].distance, 0.242, 3)
+        self.assertAlmostEqual(tree[6].distance, 0.242, places=3)
         self.assertEqual(tree[7].left, -7)
         self.assertEqual(tree[7].right, -1)
-        self.assertAlmostEqual(tree[7].distance, 0.246, 3)
+        self.assertAlmostEqual(tree[7].distance, 0.246, places=3)
         self.assertEqual(tree[8].left, 3)
         self.assertEqual(tree[8].right, -8)
-        self.assertAlmostEqual(tree[8].distance, 0.287, 3)
+        self.assertAlmostEqual(tree[8].distance, 0.287, places=3)
         self.assertEqual(tree[9].left, -9)
         self.assertEqual(tree[9].right, 8)
-        self.assertAlmostEqual(tree[9].distance, 1.936, 3)
+        self.assertAlmostEqual(tree[9].distance, 1.936, places=3)
         self.assertEqual(tree[10].left, -10)
         self.assertEqual(tree[10].right, -6)
-        self.assertAlmostEqual(tree[10].distance, 3.432, 3)
+        self.assertAlmostEqual(tree[10].distance, 3.432, places=3)
         self.assertEqual(tree[11].left, 6)
         self.assertEqual(tree[11].right, -11)
-        self.assertAlmostEqual(tree[11].distance, 3.535, 3)
+        self.assertAlmostEqual(tree[11].distance, 3.535, places=3)
       
         # Pairwise centroid-linkage clustering
         tree = treecluster(data=data2, mask=mask2, weight=weight2,
@@ -456,40 +456,40 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data2)-1)
         self.assertEqual(tree[0].left, 4)
         self.assertEqual(tree[0].right, 5)
-        self.assertAlmostEqual(tree[0].distance, 0.003, 3)
+        self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
         self.assertEqual(tree[1].left, 12)
         self.assertEqual(tree[1].right, 9)
-        self.assertAlmostEqual(tree[1].distance, 0.029, 3)
+        self.assertAlmostEqual(tree[1].distance, 0.029, places=3)
         self.assertEqual(tree[2].left, 1)
         self.assertEqual(tree[2].right, 2)
-        self.assertAlmostEqual(tree[2].distance, 0.061, 3)
+        self.assertAlmostEqual(tree[2].distance, 0.061, places=3)
         self.assertEqual(tree[3].left, -2)
         self.assertEqual(tree[3].right, 11)
-        self.assertAlmostEqual(tree[3].distance, 0.063, 3)
+        self.assertAlmostEqual(tree[3].distance, 0.063, places=3)
         self.assertEqual(tree[4].left, 10)
         self.assertEqual(tree[4].right, -4)
-        self.assertAlmostEqual(tree[4].distance, 0.109, 3)
+        self.assertAlmostEqual(tree[4].distance, 0.109, places=3)
         self.assertEqual(tree[5].left, -5)
         self.assertEqual(tree[5].right, 7)
-        self.assertAlmostEqual(tree[5].distance, 0.189, 3)
+        self.assertAlmostEqual(tree[5].distance, 0.189, places=3)
         self.assertEqual(tree[6].left, 0)
         self.assertEqual(tree[6].right, -3)
-        self.assertAlmostEqual(tree[6].distance, 0.239, 3)
+        self.assertAlmostEqual(tree[6].distance, 0.239, places=3)
         self.assertEqual(tree[7].left, 3)
         self.assertEqual(tree[7].right, -1)
-        self.assertAlmostEqual(tree[7].distance, 0.390, 3)
+        self.assertAlmostEqual(tree[7].distance, 0.390, places=3)
         self.assertEqual(tree[8].left, -7)
         self.assertEqual(tree[8].right, -8)
-        self.assertAlmostEqual(tree[8].distance, 0.382, 3)
+        self.assertAlmostEqual(tree[8].distance, 0.382, places=3)
         self.assertEqual(tree[9].left, -9)
         self.assertEqual(tree[9].right, 8)
-        self.assertAlmostEqual(tree[9].distance, 3.063, 3)
+        self.assertAlmostEqual(tree[9].distance, 3.063, places=3)
         self.assertEqual(tree[10].left, 6)
         self.assertEqual(tree[10].right, -6)
-        self.assertAlmostEqual(tree[10].distance, 4.578, 3)
+        self.assertAlmostEqual(tree[10].distance, 4.578, places=3)
         self.assertEqual(tree[11].left, -10)
         self.assertEqual(tree[11].right, -11)
-        self.assertAlmostEqual(tree[11].distance, 11.536, 3)
+        self.assertAlmostEqual(tree[11].distance, 11.536, places=3)
       
         # Pairwise maximum-linkage clustering
         tree = treecluster(data=data2, mask=mask2, weight=weight2,
@@ -497,40 +497,40 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(tree), len(data2)-1)
         self.assertEqual(tree[0].left, 5)
         self.assertEqual(tree[0].right, 4)
-        self.assertAlmostEqual(tree[0].distance, 0.003, 3)
+        self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
         self.assertEqual(tree[1].left, 9)
         self.assertEqual(tree[1].right, 12)
-        self.assertAlmostEqual(tree[1].distance, 0.029, 3)
+        self.assertAlmostEqual(tree[1].distance, 0.029, places=3)
         self.assertEqual(tree[2].left, 2)
         self.assertEqual(tree[2].right, 1)
-        self.assertAlmostEqual(tree[2].distance, 0.061, 3)
+        self.assertAlmostEqual(tree[2].distance, 0.061, places=3)
         self.assertEqual(tree[3].left, 11)
         self.assertEqual(tree[3].right, 10)
-        self.assertAlmostEqual(tree[3].distance, 0.077, 3)
+        self.assertAlmostEqual(tree[3].distance, 0.077, places=3)
         self.assertEqual(tree[4].left, -2)
         self.assertEqual(tree[4].right, -4)
-        self.assertAlmostEqual(tree[4].distance, 0.216, 3)
+        self.assertAlmostEqual(tree[4].distance, 0.216, places=3)
         self.assertEqual(tree[5].left, -3)
         self.assertEqual(tree[5].right, 0)
-        self.assertAlmostEqual(tree[5].distance, 0.266, 3)
+        self.assertAlmostEqual(tree[5].distance, 0.266, places=3)
         self.assertEqual(tree[6].left, -5)
         self.assertEqual(tree[6].right, 7)
-        self.assertAlmostEqual(tree[6].distance, 0.302, 3)
+        self.assertAlmostEqual(tree[6].distance, 0.302, places=3)
         self.assertEqual(tree[7].left, -1)
         self.assertEqual(tree[7].right, 3)
-        self.assertAlmostEqual(tree[7].distance, 0.425, 3)
+        self.assertAlmostEqual(tree[7].distance, 0.425, places=3)
         self.assertEqual(tree[8].left, -8)
         self.assertEqual(tree[8].right, -6)
-        self.assertAlmostEqual(tree[8].distance, 0.968, 3)
+        self.assertAlmostEqual(tree[8].distance, 0.968, places=3)
         self.assertEqual(tree[9].left, 8)
         self.assertEqual(tree[9].right, 6)
-        self.assertAlmostEqual(tree[9].distance, 3.975, 3)
+        self.assertAlmostEqual(tree[9].distance, 3.975, places=3)
         self.assertEqual(tree[10].left, -10)
         self.assertEqual(tree[10].right, -7)
-        self.assertAlmostEqual(tree[10].distance, 5.755, 3)
+        self.assertAlmostEqual(tree[10].distance, 5.755, places=3)
         self.assertEqual(tree[11].left, -11)
         self.assertEqual(tree[11].right, -9)
-        self.assertAlmostEqual(tree[11].distance, 22.734, 3)
+        self.assertAlmostEqual(tree[11].distance, 22.734, places=3)
 
     def test_somcluster(self):
         if TestCluster.module=='Bio.Cluster':
@@ -617,49 +617,49 @@ class TestCluster(unittest.TestCase):
         weight = numpy.array([2.0, 1.0, 0.5])
         matrix = distancematrix(data, mask=mask, weight=weight)
 
-        self.assertAlmostEqual(matrix[1][0], 1.243, 3)
+        self.assertAlmostEqual(matrix[1][0], 1.243, places=3)
 
-        self.assertAlmostEqual(matrix[2][0], 25.073, 3)
-        self.assertAlmostEqual(matrix[2][1], 44.960, 3)
+        self.assertAlmostEqual(matrix[2][0], 25.073, places=3)
+        self.assertAlmostEqual(matrix[2][1], 44.960, places=3)
 
-        self.assertAlmostEqual(matrix[3][0], 4.510, 3)
-        self.assertAlmostEqual(matrix[3][1], 5.924, 3)
-        self.assertAlmostEqual(matrix[3][2], 29.957, 3)
+        self.assertAlmostEqual(matrix[3][0], 4.510, places=3)
+        self.assertAlmostEqual(matrix[3][1], 5.924, places=3)
+        self.assertAlmostEqual(matrix[3][2], 29.957, places=3)
 
-        self.assertAlmostEqual(matrix[4][0], 3.410, 3)
-        self.assertAlmostEqual(matrix[4][1], 4.761, 3)
-        self.assertAlmostEqual(matrix[4][2], 29.203, 3)
-        self.assertAlmostEqual(matrix[4][3], 0.077, 3)
+        self.assertAlmostEqual(matrix[4][0], 3.410, places=3)
+        self.assertAlmostEqual(matrix[4][1], 4.761, places=3)
+        self.assertAlmostEqual(matrix[4][2], 29.203, places=3)
+        self.assertAlmostEqual(matrix[4][3], 0.077, places=3)
 
-        self.assertAlmostEqual(matrix[5][0], 0.040, 3)
-        self.assertAlmostEqual(matrix[5][1], 2.890, 3)
-        self.assertAlmostEqual(matrix[5][2], 34.810, 3)
-        self.assertAlmostEqual(matrix[5][3], 0.640, 3)
-        self.assertAlmostEqual(matrix[5][4], 0.490, 3)
+        self.assertAlmostEqual(matrix[5][0], 0.040, places=3)
+        self.assertAlmostEqual(matrix[5][1], 2.890, places=3)
+        self.assertAlmostEqual(matrix[5][2], 34.810, places=3)
+        self.assertAlmostEqual(matrix[5][3], 0.640, places=3)
+        self.assertAlmostEqual(matrix[5][4], 0.490, places=3)
 
-        self.assertAlmostEqual(matrix[6][0], 1.301, 3)
-        self.assertAlmostEqual(matrix[6][1], 0.447, 3)
-        self.assertAlmostEqual(matrix[6][2], 42.990, 3)
-        self.assertAlmostEqual(matrix[6][3], 3.934, 3)
-        self.assertAlmostEqual(matrix[6][4], 3.046, 3)
-        self.assertAlmostEqual(matrix[6][5], 3.610, 3)
+        self.assertAlmostEqual(matrix[6][0], 1.301, places=3)
+        self.assertAlmostEqual(matrix[6][1], 0.447, places=3)
+        self.assertAlmostEqual(matrix[6][2], 42.990, places=3)
+        self.assertAlmostEqual(matrix[6][3], 3.934, places=3)
+        self.assertAlmostEqual(matrix[6][4], 3.046, places=3)
+        self.assertAlmostEqual(matrix[6][5], 3.610, places=3)
 
-        self.assertAlmostEqual(matrix[7][0], 8.002, 3)
-        self.assertAlmostEqual(matrix[7][1], 6.266, 3)
-        self.assertAlmostEqual(matrix[7][2], 65.610, 3)
-        self.assertAlmostEqual(matrix[7][3], 12.240, 3)
-        self.assertAlmostEqual(matrix[7][4], 10.952, 3)
-        self.assertAlmostEqual(matrix[7][5], 0.000, 3)
-        self.assertAlmostEqual(matrix[7][6], 8.720, 3)
+        self.assertAlmostEqual(matrix[7][0], 8.002, places=3)
+        self.assertAlmostEqual(matrix[7][1], 6.266, places=3)
+        self.assertAlmostEqual(matrix[7][2], 65.610, places=3)
+        self.assertAlmostEqual(matrix[7][3], 12.240, places=3)
+        self.assertAlmostEqual(matrix[7][4], 10.952, places=3)
+        self.assertAlmostEqual(matrix[7][5], 0.000, places=3)
+        self.assertAlmostEqual(matrix[7][6], 8.720, places=3)
 
-        self.assertAlmostEqual(matrix[8][0], 10.659, 3)
-        self.assertAlmostEqual(matrix[8][1], 19.056, 3)
-        self.assertAlmostEqual(matrix[8][2], 0.010, 3)
-        self.assertAlmostEqual(matrix[8][3], 16.949, 3)
-        self.assertAlmostEqual(matrix[8][4], 15.734, 3)
-        self.assertAlmostEqual(matrix[8][5], 33.640, 3)
-        self.assertAlmostEqual(matrix[8][6], 18.266, 3)
-        self.assertAlmostEqual(matrix[8][7], 18.448, 3)
+        self.assertAlmostEqual(matrix[8][0], 10.659, places=3)
+        self.assertAlmostEqual(matrix[8][1], 19.056, places=3)
+        self.assertAlmostEqual(matrix[8][2], 0.010, places=3)
+        self.assertAlmostEqual(matrix[8][3], 16.949, places=3)
+        self.assertAlmostEqual(matrix[8][4], 15.734, places=3)
+        self.assertAlmostEqual(matrix[8][5], 33.640, places=3)
+        self.assertAlmostEqual(matrix[8][6], 18.266, places=3)
+        self.assertAlmostEqual(matrix[8][7], 18.448, places=3)
         clusterid, error, nfound = kmedoids(matrix, npass=1000)
         self.assertEqual(clusterid[0], 5)
         self.assertEqual(clusterid[1], 5)
@@ -670,7 +670,7 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(clusterid[6], 5)
         self.assertEqual(clusterid[7], 5)
         self.assertEqual(clusterid[8], 2)
-        self.assertAlmostEqual(error, 7.680, 3)
+        self.assertAlmostEqual(error, 7.680, places=3)
 
     def test_pca(self):
         if TestCluster.module=='Bio.Cluster':
