@@ -80,6 +80,59 @@ class MarkovModelBuilderTest(unittest.TestCase):
         test_assertion("Pseudo counts",  self.mm_builder.transition_pseudo,
                        expected_pseudo)
 
+
+    def test_set_initial_probabilities(self):
+        self.mm_builder.set_initial_probabilities({})
+        test_assertion("Equal initial probabilities by default",
+                       self.mm_builder.initial_prob, {'1': 0.5, '2': 0.5})
+
+        # initial probability sum > 1, should raise an exception
+        self.assertRaises(
+            Exception,
+            self.mm_builder.set_initial_probabilities,
+            {'1': 0.6, '2': 0.5})
+
+        # referencing invalid states should raise an exception
+        self.assertRaises(
+            Exception,
+            self.mm_builder.set_initial_probabilities,
+            {'666': 0.1})
+
+        self.mm_builder.set_initial_probabilities({'1': 0.2})
+        test_assertion("One default initial probability",
+                       self.mm_builder.initial_prob, {'1': 0.2, '2': 0.8})
+
+        self.mm_builder.set_initial_probabilities({'1': 0.9, '2': 0.1})
+        test_assertion("Set initial probabilities",
+                       self.mm_builder.initial_prob, {'1': 0.9, '2': 0.1})
+
+    def test_set_equal_probabilities(self):
+        self.mm_builder.allow_transition('1', '2', 0.05)
+        self.mm_builder.allow_transition('2', '1', 0.95)
+        self.mm_builder.set_equal_probabilities()
+
+        test_assertion("Equal initial probabilities",
+                       self.mm_builder.initial_prob,
+                       {'1': 0.5, '2': 0.5})
+        test_assertion("Equal transition probabilities",
+                       self.mm_builder.transition_prob,
+                       {('1', '2'): 0.5, ('2', '1'): 0.5})
+        test_assertion("Equal emission probabilities",
+                       self.mm_builder.emission_prob,
+                       {('2', 'A'): 0.25, ('1', 'B'): 0.25,
+                        ('1', 'A'): 0.25, ('2', 'B'): 0.25})
+
+    def test_set_random_probabilities(self):
+        self.mm_builder.allow_transition('1', '2', 0.05)
+        self.mm_builder.allow_transition('2', '1', 0.95)
+        self.mm_builder.set_random_probabilities()
+
+        test_assertion("Number of initial probabilities",
+                       len(self.mm_builder.initial_prob),
+                       len(self.mm_builder._state_alphabet.letters))
+        # To test this more thoroughly, perhaps mock random.random() and
+        # verify that it's being called as expected?
+
 class HiddenMarkovModelTest(unittest.TestCase):
     def setUp(self):
         self.mm_builder = MarkovModel.MarkovModelBuilder(NumberAlphabet(),
@@ -91,6 +144,7 @@ class HiddenMarkovModelTest(unittest.TestCase):
         self.mm_builder.allow_transition('1', '2', 1.0)
         self.mm_builder.allow_transition('2', '1', 0.5)
         self.mm_builder.allow_transition('2', '2', 0.5)
+        self.mm_builder.set_initial_probabilities({})
         self.mm = self.mm_builder.get_markov_model()
 
         state_1 = self.mm.transitions_from("1")
@@ -118,6 +172,7 @@ class HiddenMarkovModelTest(unittest.TestCase):
         self.mm_builder.allow_transition('1', '1', 0.5)
         self.mm_builder.allow_transition('1', '2', 0.5)
         self.mm_builder.allow_transition('2', '1', 1.0)
+        self.mm_builder.set_initial_probabilities({})
         self.mm = self.mm_builder.get_markov_model()
 
         state_1 = self.mm.transitions_to("1")
@@ -143,6 +198,7 @@ class HiddenMarkovModelTest(unittest.TestCase):
         """Testing allow_transition
         """
         self.mm_builder.allow_transition('1', '2', 1.0)
+        self.mm_builder.set_initial_probabilities({})
         self.mm = self.mm_builder.get_markov_model()
 
         state_1 = self.mm.transitions_from("1")
@@ -173,12 +229,82 @@ class HiddenMarkovModelTest(unittest.TestCase):
         test_assertion("States with transitions to state 2",
                        state_2, expected_state_2)
 
+    def test_simple_hmm(self):
+        """Test a simple model with 2 states and 2 symbols.
+        """
+
+        # set initial probabilities
+        prob_initial = [0.4, 0.6]
+        self.mm_builder.set_initial_probabilities(
+                {'1': prob_initial[0], '2': prob_initial[1]})
+        
+        # set transition probabilities
+        prob_transition = [[0.35, 0.65], [0.45, 0.55]]
+        self.mm_builder.allow_transition('1', '1', prob_transition[0][0])
+        self.mm_builder.allow_transition('1', '2', prob_transition[0][1])
+        self.mm_builder.allow_transition('2', '1', prob_transition[1][0])
+        self.mm_builder.allow_transition('2', '2', prob_transition[1][1])
+
+        # set emission probabilities
+        prob_emission = [[0.45, 0.55], [0.75, 0.25]]
+        self.mm_builder.set_emission_score('1', 'A', prob_emission[0][0])
+        self.mm_builder.set_emission_score('1', 'B', prob_emission[0][1])
+        self.mm_builder.set_emission_score('2', 'A', prob_emission[1][0])
+        self.mm_builder.set_emission_score('2', 'B', prob_emission[1][1])
+
+        # Check all two letter sequences using a brute force calculation
+        model = self.mm_builder.get_markov_model()
+        for first_letter in LetterAlphabet.letters:
+            for second_letter in LetterAlphabet.letters:
+                observed_emissions = [first_letter, second_letter]
+                viterbi = model.viterbi(observed_emissions, NumberAlphabet)
+                self._checkSimpleHmm(prob_initial, prob_transition,
+                                 prob_emission, viterbi, observed_emissions)
+
+    def _checkSimpleHmm(self, prob_initial, prob_transition, prob_emission,
+                         viterbi, observed_emissions):
+        max_prob = 0
+
+        # expected first and second states in the sequence, calculated below
+        seq_first_state = None
+        seq_second_state = None
+
+        # convert the observed letters 'A' or 'B' into 0 or 1
+        letter1 = ord(observed_emissions[0]) - ord('A')
+        letter2 = ord(observed_emissions[1]) - ord('A')
+
+        for first_state in NumberAlphabet.letters:
+            for second_state in NumberAlphabet.letters:
+                # compute the probability of the state sequence first_state,
+                # second_state emitting the observed_emissions
+                state1 = ord(first_state) - ord('1')
+                state2 = ord(second_state) - ord('1')
+                prob = prob_initial[state1] * prob_emission[state1][letter1] *\
+                    prob_transition[state1][state2] *\
+                    prob_emission[state2][letter2]
+                if prob > max_prob:
+                    seq_first_state = first_state
+                    seq_second_state = second_state
+                    max_prob = prob
+
+        max_prob = math.log(max_prob)
+        seq = viterbi[0]
+        prob = viterbi[1]
+        test_assertion("state sequence",
+                       str(seq),
+                       seq_first_state + seq_second_state)
+        test_assertion("log probability", round(prob, 11), round(max_prob, 11))
 
     def test_non_ergodic(self):
         """Test a non-ergodic model (meaning that some transitions are not
         allowed).
         """
 
+        # make state '1' the initial state
+        prob_1_initial = 1.0
+        self.mm_builder.set_initial_probabilities(
+                {'1': prob_1_initial})
+
         # probabilities of transitioning from state 1 to 1, and 1 to 2
         prob_1_to_1 = 0.5
         prob_1_to_2 = 0.5
@@ -192,38 +318,35 @@ class HiddenMarkovModelTest(unittest.TestCase):
         # likely emission is B. (Would be simpler just to use 1.0 and 0.0
         # emission probabilities here, but the algorithm blows up on zero
         # probabilities because of the conversion to log space.)
-        prob_emit_A_in_state_1 = 0.95
-        prob_emit_B_in_state_1 = 0.05
-        prob_emit_A_in_state_2 = 0.05
-        prob_emit_B_in_state_2 = 0.95
+        prob_1_A = 0.95
+        prob_1_B = 0.05
+        prob_2_A = 0.05
+        prob_2_B = 0.95
 
         # set emission probabilities
-        self.mm_builder.set_emission_score('1', 'A', prob_emit_A_in_state_1)
-        self.mm_builder.set_emission_score('1', 'B', prob_emit_B_in_state_1)
-        self.mm_builder.set_emission_score('2', 'A', prob_emit_A_in_state_2)
-        self.mm_builder.set_emission_score('2', 'B', prob_emit_B_in_state_2)
+        self.mm_builder.set_emission_score('1', 'A', prob_1_A)
+        self.mm_builder.set_emission_score('1', 'B', prob_1_B)
+        self.mm_builder.set_emission_score('2', 'A', prob_2_A)
+        self.mm_builder.set_emission_score('2', 'B', prob_2_B)
 
         # run the Viterbi algorithm to find the most probable state path
         model = self.mm_builder.get_markov_model()
         observed_emissions = ['A', 'B']
-        viterbi=model.viterbi(observed_emissions, NumberAlphabet)
-        seq=viterbi[0]
-        prob=viterbi[1]
+        viterbi = model.viterbi(observed_emissions, NumberAlphabet)
+        seq = viterbi[0]
+        prob = viterbi[1]
 
         # the most probable path must be from state 1 to state 2
         test_assertion("most probable path", str(seq), '12')
 
-        # The probability of that path is the probability of transitioning
-        # from state 1 to state 1 (1 -> 1), then emitting an A, then
-        # transitioning 1 -> 2, then emitting a B. That first hidden
-        # transition (not part of the published state sequence) from
-        # 1 -> 1 is not a real transition, rather it's an implementation
-        # detail that determines the initial state of the sequence.
+        # The probability of that path is the probability of starting in 
+        # state 1, then emitting an A, then transitioning 1 -> 2, then 
+        # emitting a B.
         # Note that probabilities are converted into log space.
-        expected_prob = math.log(prob_1_to_1)\
-        + math.log(prob_emit_A_in_state_1)\
+        expected_prob = math.log(prob_1_initial)\
+        + math.log(prob_1_A)\
         + math.log(prob_1_to_2)\
-        + math.log(prob_emit_B_in_state_2)
+        + math.log(prob_2_B)
         test_assertion("log probability of most probable path",
                        prob, expected_prob)
 
@@ -257,7 +380,7 @@ class ScaledDPAlgorithmsTest(unittest.TestCase):
 class AbstractTrainerTest(unittest.TestCase):
     def setUp(self):
         # set up a bogus HMM and our trainer
-        hmm = MarkovModel.HiddenMarkovModel({}, {}, {}, {})
+        hmm = MarkovModel.HiddenMarkovModel({}, {}, {}, {}, {})
         self.test_trainer = Trainer.AbstractTrainer(hmm)
     
     def test_ml_estimator(self):
