@@ -11,19 +11,11 @@ import tempfile
 import unittest
 from itertools import chain
 
-# Python 2.4 doesn't have ElementTree, which PhyloXMLIO needs
-from Bio import MissingPythonDependencyError
-try:
-    from Bio.Phylo import PhyloXML as PX, PhyloXMLIO
-except ImportError:
-    raise MissingPythonDependencyError(
-            "Install an ElementTree implementation if you want to use "
-            "Bio.Phylo to parse phyloXML files.")
-
 from Bio import Alphabet
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
 from Bio.Align import MultipleSeqAlignment
+from Bio.Phylo import PhyloXML as PX, PhyloXMLIO
 
 # Example PhyloXML files
 EX_APAF = 'PhyloXML/apaf.xml'
@@ -235,7 +227,11 @@ class TreeTests(unittest.TestCase):
 
     def test_BinaryCharacters(self):
         """Instantiation of BinaryCharacters objects."""
-        tree = PhyloXMLIO.parse(EX_DOLLO).next()
+        #Because we short circult interation, must close handle explicitly
+        #to avoid a ResourceWarning
+        handle = open(EX_DOLLO)
+        tree = PhyloXMLIO.parse(handle).next()
+        handle.close()
         bchars = tree.clade[0,0].binary_characters
         self.assertTrue(isinstance(bchars, PX.BinaryCharacters))
         self.assertEqual(bchars.type, 'parsimony inferred')
@@ -402,6 +398,7 @@ class TreeTests(unittest.TestCase):
     def test_Reference(self):
         """Instantiation of Reference objects."""
         #Because we short circult interation, must close handle explicitly
+        #to avoid a ResourceWarning
         handle = open(EX_DOLLO)
         tree = PhyloXMLIO.parse(handle).next()
         handle.close()
