@@ -16,92 +16,87 @@ class SimpleEnzyme(unittest.TestCase):
         self.ecosite_seq = base_seq + Seq(EcoRI.site,
                 IUPACAmbiguousDNA()) + base_seq
 
-    def tearDown(self):
-        pass
-
     def test_eco_cutting(self):
         """Test basic cutting with EcoRI.
         """
-        assert EcoRI.site == 'GAATTC'
-        assert EcoRI.is_blunt() == False
-        assert EcoRI.is_5overhang() == True
-        assert EcoRI.is_3overhang() == False
-        assert EcoRI.elucidate() == "G^AATT_C"
-        assert EcoRI.search(self.ecosite_seq) == [6]
+        self.assertEqual(EcoRI.site, 'GAATTC')
+        self.assertFalse(EcoRI.is_blunt())
+        self.assertTrue(EcoRI.is_5overhang())
+        self.assertFalse(EcoRI.is_3overhang())
+        self.assertEqual(EcoRI.elucidate(), "G^AATT_C")
+        self.assertEqual(EcoRI.search(self.ecosite_seq), [6])
 
         parts = EcoRI.catalyse(self.ecosite_seq)
-        assert len(parts) == 2
-        assert parts[1].tostring() == "AATTCAAAA"
+        self.assertEqual(len(parts), 2)
+        self.assertEqual(parts[1].tostring(), "AATTCAAAA")
         parts = EcoRI.catalyze(self.ecosite_seq)
-        assert len(parts) == 2
+        self.assertEqual(len(parts), 2)
 
     def test_circular_sequences(self):
         """Deal with cutting circular sequences.
         """
         parts = EcoRI.catalyse(self.ecosite_seq, linear = False)
-        assert len(parts) == 1
+        self.assertEqual(len(parts), 1)
         locations = EcoRI.search(parts[0], linear = False)
-        assert locations == [1]
+        self.assertEqual(locations, [1])
+
 
 class EnzymeComparison(unittest.TestCase):
     """Tests for comparing various enzymes.
     """
-    def setUp(self):
-        pass
-
-    def tearDown(self):
-        pass
-
     def test_basic_isochizomers(self):
         """Test to be sure isochizomer and neoschizomers are as expected.
         """
-        assert Acc65I.isoschizomers() == [Asp718I, KpnI]
-        assert Acc65I.elucidate() == 'G^GTAC_C'
-        assert Asp718I.elucidate() == 'G^GTAC_C'
-        assert KpnI.elucidate() == 'G_GTAC^C'
+        self.assertEqual(Acc65I.isoschizomers(), [Asp718I, KpnI])
+        self.assertEqual(Acc65I.elucidate(), 'G^GTAC_C')
+        self.assertEqual(Asp718I.elucidate(), 'G^GTAC_C')
+        self.assertEqual(KpnI.elucidate(), 'G_GTAC^C')
 
     def test_comparisons(self):
         """Comparison operators between iso and neoschizomers.
         """
-        assert Acc65I == Acc65I
-        assert Acc65I != KpnI
-        assert not(Acc65I == Asp718I)
-        assert not(Acc65I != Asp718I)
-        assert Acc65I != EcoRI
+        self.assertEqual(Acc65I, Acc65I)
+        self.assertNotEqual(Acc65I, KpnI)
+        self.assertFalse(Acc65I == Asp718I)
+        self.assertFalse(Acc65I != Asp718I)
+        self.assertNotEqual(Acc65I, EcoRI)
 
-        assert Acc65I >> KpnI
-        assert not(Acc65I >> Asp718I)
+        self.assertTrue(Acc65I >> KpnI)
+        self.assertFalse(Acc65I >> Asp718I)
+
+        self.assertTrue(Acc65I % Asp718I)
+        self.assertTrue(Acc65I % Acc65I)
+        self.assertFalse(Acc65I % KpnI)
 
-        assert Acc65I % Asp718I
-        assert Acc65I % Acc65I
-        assert not(Acc65I % KpnI)
 
 class RestrictionBatches(unittest.TestCase):
     """Tests for dealing with batches of restriction enzymes.
     """
-    def setUp(self):
-        pass
-
-    def tearDown(self):
-        pass
-
     def test_creating_batch(self):
         """Creating and modifying a restriction batch.
         """
         batch = RestrictionBatch([EcoRI])
         batch.add(KpnI)
         batch += EcoRV
-        assert len(batch) == 3
+        self.assertEqual(len(batch), 3)
+
+        # The usual way to test batch membership
+        self.assertTrue(EcoRV in batch)
+        self.assertTrue(EcoRI in batch)
+        self.assertTrue(KpnI in batch)
+        self.assertTrue(SmaI not in batch)
+        # Syntax sugar for the above
+        self.assertTrue('EcoRV' in batch)
+        self.assertFalse('SmaI' in batch)
 
         batch.get(EcoRV)
-        try:
-            batch.get(SmaI)
-            raise AssertionError("No error with non-existent enzyme.")
-        except ValueError:
-            pass
+        self.assertRaises(ValueError, batch.get, SmaI)
 
         batch.remove(EcoRV)
-        assert len(batch) == 2
+        self.assertEqual(len(batch), 2)
+
+        self.assertTrue(EcoRV not in batch)
+        self.assertTrue('EcoRV' not in batch)
 
     def test_batch_analysis(self):
         """Sequence analysis with a restriction batch.
@@ -111,7 +106,8 @@ class RestrictionBatches(unittest.TestCase):
         batch = RestrictionBatch([EcoRV, EcoRI])
 
         hits = batch.search(seq)
-        assert hits[EcoRV] == [8] and hits[EcoRI] == [16]
+        self.assertEqual(hits[EcoRV], [8])
+        self.assertEqual(hits[EcoRI], [16])
 
 
 if __name__ == "__main__":
