@@ -33,14 +33,17 @@ dna_alphas = [Alphabet.generic_dna]
 rna_alphas = [Alphabet.generic_rna]
 nucleotide_alphas = [Alphabet.generic_nucleotide,
                      Alphabet.Gapped(Alphabet.generic_nucleotide)]
-no_alpha_formats = ["fasta","clustal","phylip","tab","ig","stockholm","emboss",
-                    "fastq","fastq-solexa","fastq-illumina","qual"]
+no_alpha_formats = ["fasta","clustal","phylip","phylip-relaxed",
+                    "phylip-sequential","tab","ig",
+                    "stockholm","emboss", "fastq","fastq-solexa",
+                    "fastq-illumina","qual"]
 possible_unknown_seq_formats = ["qual", "genbank", "gb", "embl", "imgt"]
 
 #List of formats including alignment only file formats we can read AND write.
 #The list is initially hard coded to preserve the original order of the unit
 #test output, with any new formats added since appended to the end.
-test_write_read_alignment_formats = ["fasta","clustal","phylip","stockholm"]
+test_write_read_alignment_formats = ["fasta","clustal","phylip","stockholm",
+                                     "phylip-relaxed"]
 for format in sorted(SeqIO._FormatToWriter):
     if format not in test_write_read_alignment_formats:
         test_write_read_alignment_formats.append(format)
@@ -151,10 +154,11 @@ test_files = [ \
     ("embl",   False, 'EMBL/AAA03323.embl', 1), # 2008, PA line but no AC
     ("embl",   False, 'EMBL/AE017046.embl', 1), #See also NC_005816.gb
     ("embl",   False, 'EMBL/Human_contigs.embl', 2), #contigs, no sequences
+    ("embl",   False, 'EMBL/location_wrap.embl', 1), #wrapped locations and unspecified type
     ("embl",   False, 'EMBL/A04195.imgt', 1), # features over indented for EMBL
     ("imgt",   False, 'EMBL/A04195.imgt', 1), # features over indented for EMBL
     ("stockholm", True,  'Stockholm/simple.sth', 2),
-    ("stockholm", True,  'Stockholm/funny.sth', 5),
+    ("stockholm", True,  'Stockholm/funny.sth', 6),
 #Following PHYLIP files are currently only used here and in test_AlignIO.py,
 #and are mostly from Joseph Felsenstein's PHYLIP v3.6 documentation:
     ("phylip", True,  'Phylip/reference_dna.phy', 6),
@@ -200,8 +204,35 @@ test_files = [ \
     ("fastq-illumina", False,'Quality/illumina_faked.fastq', 1),
     ("fastq-solexa", False, 'Quality/solexa_faked.fastq', 1),
     ("fastq-solexa", True, 'Quality/solexa_example.fastq', 5),
+#Following examples are also used in test_SeqXML.py
+    ("seqxml", False, 'SeqXML/dna_example.xml', 4),
+    ("seqxml", False, 'SeqXML/rna_example.xml', 5),
+    ("seqxml", False, 'SeqXML/protein_example.xml', 5),
+#Following examples are also used in test_SeqIO_AbiIO.py
+    ("abi", False, 'Abi/310.ab1', 1),
+    ("abi", False, 'Abi/3100.ab1', 1),
+    ("abi", False, 'Abi/3730.ab1', 1),
     ]
 
+class ForwardOnlyHandle(object):
+    """Mimic a network handle without seek and tell methods etc."""
+    def __init__(self, handle):
+        self._handle = handle
+
+    def __iter__(self):
+        return iter(self._handle)
+
+    def read(self, length=None):
+        if length is None:
+            return self._handle.read()
+        else:
+            return self._handle.read(length)
+
+    def readline(self):
+        return self._handle.readline()
+
+    def close(self):
+        return self._handle.close()
 
 def compare_record(record_one, record_two):
     """This is meant to be a strict comparison for exact agreement..."""
@@ -282,13 +313,13 @@ def check_simple_write_read(records, indent=" "):
            #rather long, and it seems a bit pointless to record them.
            continue
         print indent+"Checking can write/read as '%s' format" % format
-        
+
         #Going to write to a handle...
         if format in SeqIO._BinaryFormats:
             handle = BytesIO()
         else:
             handle = StringIO()
-        
+
         try:
             c = SeqIO.write(sequences=records, handle=handle, format=format)
             assert c == len(records)
@@ -308,8 +339,9 @@ def check_simple_write_read(records, indent=" "):
                 print "Failed: Probably len() of None"
             else:
                 print indent+"Failed: %s" % str(e)
-            assert format != t_format, \
-                   "Should be able to re-write in the original format!"
+            if records[0].seq.alphabet.letters is not None:
+                assert format != t_format, \
+                       "Should be able to re-write in the original format!"
             #Carry on to the next format:
             continue
 
@@ -349,9 +381,12 @@ def check_simple_write_read(records, indent=" "):
                 assert r1.seq.tostring() == r2.seq.tostring()
             #Beware of different quirks and limitations in the
             #valid character sets and the identifier lengths!
-            if format=="phylip":
+            if format in ["phylip", "phylip-sequential"]:
                 assert r1.id.replace("[","").replace("]","")[:10] == r2.id, \
                        "'%s' vs '%s'" % (r1.id, r2.id)
+            elif format=="phylip-relaxed":
+                assert r1.id.replace(" ", "").replace(':', '|') == r2.id, \
+                        "'%s' vs '%s'" % (r1.id, r2.id)
             elif format=="clustal":
                 assert r1.id.replace(" ","_")[:30] == r2.id, \
                        "'%s' vs '%s'" % (r1.id, r2.id)
@@ -388,12 +423,14 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
         mode = "rb"
     else:
         mode = "r"
-    
+
     print "Testing reading %s format file %s" % (t_format, t_filename)
     assert os.path.isfile(t_filename), t_filename
 
     #Try as an iterator using handle
-    records  = list(SeqIO.parse(handle=open(t_filename,mode), format=t_format))
+    h = open(t_filename,mode)
+    records  = list(SeqIO.parse(handle=h, format=t_format))
+    h.close()
     assert len(records)  == t_count, \
          "Found %i records but expected %i" % (len(records), t_count)
 
@@ -405,7 +442,8 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
 
     #Try using the iterator with the next() method
     records3 = []
-    seq_iterator = SeqIO.parse(handle=open(t_filename,mode), format=t_format)
+    h = open(t_filename,mode)
+    seq_iterator = SeqIO.parse(handle=h, format=t_format)
     while True:
         try:
             record = seq_iterator.next()
@@ -413,9 +451,11 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
             break
         assert record is not None, "Should raise StopIteration not return None"
         records3.append(record)
-        
+    h.close()
+
     #Try a mixture of next() and list (a torture test!)
-    seq_iterator = SeqIO.parse(handle=open(t_filename,mode), format=t_format)
+    h = open(t_filename,mode)
+    seq_iterator = SeqIO.parse(handle=h, format=t_format)
     try:
         record = seq_iterator.next()
     except StopIteration:
@@ -426,9 +466,16 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
     else:
         records4 = []
     assert len(records4) == t_count
+    h.close()
 
     #Try a mixture of next() and for loop (a torture test!)
-    seq_iterator = SeqIO.parse(handle=open(t_filename,mode), format=t_format)
+    #with a forward-only-handle
+    if t_format == "abi":
+        #Temp hack
+        h = open(t_filename, mode)
+    else:
+        h = ForwardOnlyHandle(open(t_filename, mode))
+    seq_iterator = SeqIO.parse(h, format=t_format)
     try:
         record = seq_iterator.next()
     except StopIteration:
@@ -440,6 +487,7 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
     else:
         records5 = []
     assert len(records5) == t_count
+    h.close()
 
     for i in range(t_count):
         record = records[i]
@@ -469,8 +517,8 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
                 "Bad cross reference in dbxrefs: %s" % repr(ref)
         assert len(record.dbxrefs) == len(record.dbxrefs), \
                "Repeated cross reference in dbxrefs: %s" % repr(record.dbxrefs)
-                
-            
+
+
         #Check the lists obtained by the different methods agree
         assert compare_record(record, records2[i])
         assert compare_record(record, records3[i])
@@ -479,7 +527,7 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
 
         if i < 3:
             print record_summary(record)
-    # Only printed the only first three records: 0,1,2 
+    # Only printed the only first three records: 0,1,2
     if t_count > 4:
         print " ..."
     if t_count > 3:
@@ -487,7 +535,7 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
 
     # Check Bio.SeqIO.read(...)
     if t_count == 1:
-        record = SeqIO.read(handle=open(t_filename), format=t_format)
+        record = SeqIO.read(handle=open(t_filename,mode), format=t_format)
         assert isinstance(record, SeqRecord)
     else:
         try:
@@ -500,9 +548,11 @@ for (t_format, t_alignment, t_filename, t_count) in test_files:
     # Check alphabets
     for record in records:
         base_alpha = Alphabet._get_base_alphabet(record.seq.alphabet)
-        assert isinstance(base_alpha, Alphabet.SingleLetterAlphabet)
-        if t_format in no_alpha_formats:
-            assert base_alpha == Alphabet.single_letter_alphabet # Too harsh?
+        if isinstance(base_alpha, Alphabet.SingleLetterAlphabet):
+            if t_format in no_alpha_formats:
+                assert base_alpha == Alphabet.single_letter_alphabet # Too harsh?
+        else:
+            base_alpha = None
     if base_alpha is None:
         good = []
         bad =[]
