@@ -1,4 +1,4 @@
-# Copyright 2009-2010 by Peter Cock.  All rights reserved.
+# Copyright 2009-2011 by Peter Cock.  All rights reserved.
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -170,8 +170,11 @@ def make_join_feature(f_list, ftype="misc_feature"):
         f.type=ftype
         f.location_operator="join"
     jf = SeqFeature(FeatureLocation(f_list[0].location.start,
-                                    f_list[-1].location.end),
-                    type=ftype, strand=strand, location_operator="join")
+                                    f_list[-1].location.end,
+                                    strand),
+                    type=ftype, location_operator="join")
+    assert jf.location.strand == strand
+    assert jf.strand == strand
     jf.sub_features = f_list
     return jf
 
@@ -205,6 +208,12 @@ class SeqFeatureExtractionWritingReading(unittest.TestCase):
         self.assertTrue(isinstance(new, Seq))
         self.assertEqual(str(new), answer_str)
 
+        if not feature.sub_features:
+            new = parent_seq[feature.location.start:feature.location.end]
+            if feature.strand == -1:
+                new = reverse_complement(new)
+            self.assertEqual(str(new), answer_str)
+
         new = feature.extract(str(parent_seq))
         self.assertTrue(isinstance(new, str))
         self.assertEqual(new, answer_str)
@@ -264,6 +273,8 @@ class SeqFeatureExtractionWritingReading(unittest.TestCase):
         """Feature on RNA (simple, default strand)"""
         s = Seq("GAUCRYWSMKHBVDN", generic_rna)
         f = SeqFeature(FeatureLocation(5,10))
+        self.assertEqual(f.strand, None)
+        self.assertEqual(f.location.strand, None)
         self.check(s, f, "YWSMK", "6..10")
 
     def test_simple_dna(self):
@@ -306,12 +317,16 @@ class SeqFeatureExtractionWritingReading(unittest.TestCase):
         """Feature on DNA (simple, strand +1)"""
         s = Seq("GATCRYWSMKHBVDN", generic_dna)
         f = SeqFeature(FeatureLocation(5,10), strand=1)
+        self.assertEqual(f.strand, +1)
+        self.assertEqual(f.location.strand, +1)
         self.check(s, f, "YWSMK", "6..10")
         
     def test_simple_dna_strand_minus(self):
         """Feature on DNA (simple, strand -1)"""
         s = Seq("GATCRYWSMKHBVDN", generic_dna)
         f = SeqFeature(FeatureLocation(5,10), strand=-1)
+        self.assertEqual(f.strand, -1)
+        self.assertEqual(f.location.strand, -1)
         self.check(s, f, "MKSWR", "complement(6..10)")
 
     def test_simple_dna_join(self):
@@ -386,8 +401,8 @@ class SeqFeatureExtractionWritingReading(unittest.TestCase):
         """Feature on protein (fuzzy join)"""
         s = Seq("ABCDEFGHIJKLMNOPQRSTUVWXYZ", generic_protein)
         f1 = SeqFeature(FeatureLocation(BeforePosition(5),10))
-        f2 = SeqFeature(FeatureLocation(OneOfPosition((ExactPosition(15),
-                                                       ExactPosition(16))),
+        f2 = SeqFeature(FeatureLocation(OneOfPosition(15, (ExactPosition(15),
+                                                           ExactPosition(16))),
                                         AfterPosition(20)))
         f = make_join_feature([f1,f2])
         self.check(s, f, "FGHIJ"+"PQRST", "join(<6..10,one-of(16,17)..>20)")
@@ -415,8 +430,8 @@ class SeqFeatureExtractionWritingReading(unittest.TestCase):
     def test_protein_oneof(self):
         """Feature on protein (one-of positions)"""
         s = Seq("ABCDEFGHIJKLMNOPQRSTUVWXYZ", generic_protein)
-        start = OneOfPosition((ExactPosition(5),ExactPosition(7)))
-        end = OneOfPosition((ExactPosition(10),ExactPosition(11)))
+        start = OneOfPosition(5, (ExactPosition(5),ExactPosition(7)))
+        end = OneOfPosition(11, (ExactPosition(10),ExactPosition(11)))
         f = SeqFeature(FeatureLocation(start,10))
         self.check(s, f, "FGHIJ", "one-of(6,8)..10")
         f = SeqFeature(FeatureLocation(start,end))
@@ -593,11 +608,12 @@ class FeatureWriting(unittest.TestCase):
             self.assertEqual(sub_f.strand, -1)
         self.assertEqual(f._flip(100).strand, -1)
         
-        f1 = SeqFeature(FeatureLocation(OneOfPosition([ExactPosition(107),
-                                                       ExactPosition(110)]),120),
+        f1 = SeqFeature(FeatureLocation(OneOfPosition(107, [ExactPosition(107),
+                                                            ExactPosition(110)]),
+                                        120),
                         strand=+1)
         f2 = SeqFeature(FeatureLocation(125,140), strand=+1)
-        f3 = SeqFeature(FeatureLocation(145,WithinPosition(150,10)), strand=+1)
+        f3 = SeqFeature(FeatureLocation(145,WithinPosition(160, left=150, right=160)), strand=+1)
         f = make_join_feature([f1,f2,f3], "CDS")
         self.assertEqual(_insdc_feature_location_string(f,500),
                          "join(one-of(108,111)..120,126..140,146..(150.160))")
@@ -611,7 +627,7 @@ class FeatureWriting(unittest.TestCase):
         self.record.features.append(f)
         
         f1 = SeqFeature(FeatureLocation(BeforePosition(210),220), strand=-1)
-        f2 = SeqFeature(FeatureLocation(225,WithinPosition(240,4)), strand=-1)
+        f2 = SeqFeature(FeatureLocation(225,WithinPosition(244, left=240, right=244)), strand=-1)
         f = make_join_feature([f1,f2], "gene")
         self.assertEqual(_insdc_feature_location_string(f,500),
                          "complement(join(<211..220,226..(240.244)))")
@@ -625,10 +641,11 @@ class FeatureWriting(unittest.TestCase):
         self.record.features.append(f)
         
         f1 = SeqFeature(FeatureLocation(AfterPosition(310),320), strand=-1)
-        f2 = SeqFeature(FeatureLocation(325,OneOfPosition([ExactPosition(340),
-                                                           ExactPosition(337)])),
+        #Note - is one-of(340,337) allowed or should it be one-of(337,340)?
+        f2 = SeqFeature(FeatureLocation(325,OneOfPosition(340, [ExactPosition(340),
+                                                                ExactPosition(337)])),
                         strand=-1)
-        f3 = SeqFeature(FeatureLocation(345,WithinPosition(350,5)), strand=-1)
+        f3 = SeqFeature(FeatureLocation(345,WithinPosition(355, left=350, right=355)), strand=-1)
         f = make_join_feature([f1,f2,f3], "CDS")
         self.assertEqual(_insdc_feature_location_string(f,500),
                          "complement(join(>311..320,326..one-of(340,337),346..(350.355)))")
@@ -788,7 +805,7 @@ class FeatureWriting(unittest.TestCase):
     def test_oneof(self):
         """Features: write/read simple one-of locations."""
         s = "N" * 100
-        start = OneOfPosition([ExactPosition(0),ExactPosition(3),ExactPosition(6)])
+        start = OneOfPosition(0, [ExactPosition(0),ExactPosition(3),ExactPosition(6)])
         f = SeqFeature(FeatureLocation(start,21), strand=+1, type="CDS")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "one-of(1,4,7)..21")
@@ -799,8 +816,8 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, -1)
         self.record.features.append(f)
         
-        start = OneOfPosition([ExactPosition(x) for x in [10,13,16]])
-        end = OneOfPosition([ExactPosition(x) for x in [41,44,50]])
+        start = OneOfPosition(10, [ExactPosition(x) for x in [10,13,16]])
+        end = OneOfPosition(50, [ExactPosition(x) for x in [41,44,50]])
         f = SeqFeature(FeatureLocation(start,end), strand=+1, type="gene")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "one-of(11,14,17)..one-of(41,44,50)")
@@ -811,7 +828,7 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, -1)
         self.record.features.append(f)
         
-        end = OneOfPosition([ExactPosition(x) for x in [30,33]])
+        end = OneOfPosition(33, [ExactPosition(x) for x in [30,33]])
         f = SeqFeature(FeatureLocation(27,end), strand=+1, type="gene")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "28..one-of(30,33)")
@@ -822,7 +839,7 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, -1)
         self.record.features.append(f)
         
-        start = OneOfPosition([ExactPosition(x) for x in [36,40]])
+        start = OneOfPosition(36, [ExactPosition(x) for x in [36,40]])
         f = SeqFeature(FeatureLocation(start,46), strand=-1, type="CDS")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "complement(one-of(37,41)..46)")
@@ -833,8 +850,8 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, +1)
         self.record.features.append(f)
         
-        start = OneOfPosition([ExactPosition(x) for x in [45,60]])
-        end = OneOfPosition([ExactPosition(x) for x in [70,90]])
+        start = OneOfPosition(45, [ExactPosition(x) for x in [45,60]])
+        end = OneOfPosition(90, [ExactPosition(x) for x in [70,90]])
         f = SeqFeature(FeatureLocation(start,end), strand=-1, type="CDS")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "complement(one-of(46,61)..one-of(70,90))")
@@ -845,7 +862,7 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, +1)
         self.record.features.append(f)
         
-        end = OneOfPosition([ExactPosition(x) for x in [60,63]])
+        end = OneOfPosition(63, [ExactPosition(x) for x in [60,63]])
         f = SeqFeature(FeatureLocation(55,end), strand=-1, type="tRNA")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "complement(56..one-of(60,63))")
@@ -861,7 +878,7 @@ class FeatureWriting(unittest.TestCase):
     def test_within(self):
         """Features: write/read simple within locations."""
         s = "N" * 100
-        f = SeqFeature(FeatureLocation(WithinPosition(2,6),10), \
+        f = SeqFeature(FeatureLocation(WithinPosition(2, left=2, right=8),10), \
                        strand=+1, type="CDS")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "(3.9)..10")
@@ -872,8 +889,8 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, -1)
         self.record.features.append(f)
         
-        f = SeqFeature(FeatureLocation(WithinPosition(12,6),
-                                       WithinPosition(20,8)), \
+        f = SeqFeature(FeatureLocation(WithinPosition(12, left=12, right=18),
+                                       WithinPosition(28, left=20, right=28)), \
                        strand=+1, type="CDS")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "(13.19)..(20.28)")
@@ -884,7 +901,7 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, -1)
         self.record.features.append(f)
         
-        f = SeqFeature(FeatureLocation(25,WithinPosition(30,3)), \
+        f = SeqFeature(FeatureLocation(25,WithinPosition(33, left=30, right=33)), \
                        strand=+1, type="misc_feature")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "26..(30.33)")
@@ -895,7 +912,7 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, -1)
         self.record.features.append(f)
         
-        f = SeqFeature(FeatureLocation(WithinPosition(35,4),40), \
+        f = SeqFeature(FeatureLocation(WithinPosition(35, left=35, right=39),40), \
                        strand=-1, type="rRNA")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "complement((36.40)..40)")
@@ -905,8 +922,8 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, +1)
         self.record.features.append(f)
         
-        f = SeqFeature(FeatureLocation(WithinPosition(45,2),
-                                       WithinPosition(50,3)), \
+        f = SeqFeature(FeatureLocation(WithinPosition(45, left=45, right=47),
+                                       WithinPosition(53, left=50, right=53)), \
                        strand=-1, type="repeat_region")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "complement((46.48)..(50.53))")
@@ -917,7 +934,7 @@ class FeatureWriting(unittest.TestCase):
         self.assertEqual(f._flip(100).strand, +1)
         self.record.features.append(f)
         
-        f = SeqFeature(FeatureLocation(55,WithinPosition(60,5)), \
+        f = SeqFeature(FeatureLocation(55,WithinPosition(65, left=60, right=65)), \
                        strand=-1, type="CDS")
         self.assertEqual(_insdc_feature_location_string(f,100),
                          "complement(56..(60.65))")
@@ -985,6 +1002,13 @@ class NC_005816(NC_000932):
             return
         gb_record = SeqIO.read(open(self.gb_filename),"genbank")
         embl_record = SeqIO.read(open(self.embl_filename),"embl")
+        if len(embl_record.features) < len(gb_record.features):
+            #Used to match, but I've update the GenBank files
+            #which now has lots of misc_feature entries not in EMBL
+            embl_record.features = [f for f in embl_record.features \
+                                    if f.type != "misc_feature"]
+            gb_record.features = [f for f in gb_record.features \
+                                  if f.type != "misc_feature"]
         return compare_record(gb_record, embl_record, expect_minor_diffs=True)
 
     def test_Translations(self):
@@ -1013,6 +1037,12 @@ class NC_005816(NC_000932):
         if self.emblname is None:
             return
         embl_record = SeqIO.read(open(self.embl_filename),"embl")
+        if len(embl_record.features) < len(gb_record.features):
+            #Hack since now out of sync for NC_005816
+            embl_record.features = [f for f in embl_record.features \
+                                    if f.type != "misc_feature"]
+            gb_record.features = [f for f in gb_record.features \
+                                  if f.type != "misc_feature"]
         compare_record(gb_record, embl_record, expect_minor_diffs=True)
 
     def test_Features(self):
