@@ -1,3 +1,4 @@
+
 #!/usr/bin/env python
 """test_align.py
 
@@ -13,43 +14,41 @@ import os
 
 # biopython
 from Bio import Alphabet
-from Bio import Seq
+from Bio.Seq import Seq
+from Bio.SeqRecord import SeqRecord
 from Bio.Alphabet import IUPAC
-from Bio import Clustalw
 from Bio.Align import AlignInfo
 from Bio import AlignIO
 from Bio.SubsMat import FreqTable
-from Bio.Align.Generic import Alignment
+from Bio.Align import MultipleSeqAlignment
 
 #Very simple tests on an empty alignment
-alignment = Alignment(Alphabet.generic_alphabet)
+alignment = MultipleSeqAlignment([], Alphabet.generic_alphabet)
 assert alignment.get_alignment_length() == 0
-assert alignment.get_all_seqs() == []
+assert len(alignment) == 0
 del alignment
 
 #Basic tests on simple three string alignment
-alignment = Alignment(Alphabet.generic_alphabet)
+alignment = MultipleSeqAlignment([], Alphabet.generic_alphabet)
 letters = "AbcDefGhiJklMnoPqrStuVwxYz"
-alignment.add_sequence("mixed", letters)
-alignment.add_sequence("lower", letters.lower())
-alignment.add_sequence("upper", letters.upper())
+alignment.append(SeqRecord(Seq(letters), id="mixed"))
+alignment.append(SeqRecord(Seq(letters.lower()), id="lower"))
+alignment.append(SeqRecord(Seq(letters.upper()), id="upper"))
 assert alignment.get_alignment_length() == 26
-assert len(alignment.get_all_seqs()) == 3
-assert alignment.get_seq_by_num(0).tostring() == letters
-assert alignment.get_seq_by_num(1).tostring() == letters.lower()
-assert alignment.get_seq_by_num(2).tostring() == letters.upper()
-assert alignment.get_all_seqs()[0].description == "mixed"
-assert alignment.get_all_seqs()[1].description == "lower"
-assert alignment.get_all_seqs()[2].description == "upper"
+assert len(alignment) == 3
+assert str(alignment[0].seq) == letters
+assert str(alignment[1].seq) == letters.lower()
+assert str(alignment[2].seq) == letters.upper()
+assert alignment[0].id == "mixed"
+assert alignment[1].id == "lower"
+assert alignment[2].id == "upper"
 for (col, letter) in enumerate(letters):
-    assert alignment.get_column(col) == letter \
-                                      + letter.lower() \
-                                      + letter.upper()
+    assert alignment[:,col] == letter + letter.lower() + letter.upper()
 #Check row extractions:
 assert alignment[0].id == "mixed"
 assert alignment[-1].id == "upper"
 #Check sub-alignment extraction by row slicing:
-assert isinstance(alignment[::-1], Alignment)
+assert isinstance(alignment[::-1], MultipleSeqAlignment)
 assert alignment[::-1][0].id == "upper"
 assert alignment[::-1][2].id == "mixed"
 
@@ -66,17 +65,17 @@ for name in test_names:
 
 for test_file in test_files:
     # parse the alignment file and get an aligment object
-    alignment = Clustalw.parse_file(test_file)
+    alignment = AlignIO.read(test_file, "clustal")
 
     # print the alignment back out
-    print alignment
+    print alignment.format("clustal")
 
-alignment = Clustalw.parse_file(os.path.join(test_dir, test_names[0]))
+alignment = AlignIO.read(os.path.join(test_dir, test_names[0]), "clustal",
+                         alphabet = Alphabet.Gapped(IUPAC.unambiguous_dna))
 
 # test the base alignment stuff
 print 'all_seqs...'
-all_seqs = alignment.get_all_seqs()
-for seq_record in all_seqs:
+for seq_record in alignment:
     print 'description:', seq_record.description
     print 'seq:', repr(seq_record.seq)
 print 'length:', alignment.get_alignment_length()
@@ -84,7 +83,7 @@ print 'length:', alignment.get_alignment_length()
 print 'Calculating summary information...'
 align_info = AlignInfo.SummaryInfo(alignment)
 consensus = align_info.dumb_consensus()
-assert isinstance(consensus, Seq.Seq)
+assert isinstance(consensus, Seq)
 print 'consensus:', repr(consensus)
 
 
@@ -102,14 +101,14 @@ print 'defaulting to a consensus sequence...'
 print align_info.pos_specific_score_matrix(chars_to_ignore = ['N'])
 
 print 'with a selected sequence...'
-second_seq = alignment.get_seq_by_num(1)
+second_seq = alignment[1].seq
 print align_info.pos_specific_score_matrix(second_seq, ['N'])
 
 print 'information content'
-print 'part of alignment:', align_info.information_content(5, 50,
-                                chars_to_ignore = ['N'])
-print 'entire alignment:', align_info.information_content(
-                                chars_to_ignore = ['N'])
+print 'part of alignment: %0.2f' \
+      % align_info.information_content(5, 50, chars_to_ignore = ['N'])
+print 'entire alignment: %0.2f' \
+      % align_info.information_content(chars_to_ignore = ['N'])
 
 print 'relative information content'
 e_freq = {'G' : 0.25,
@@ -120,34 +119,33 @@ e_freq = {'G' : 0.25,
 e_freq_table = FreqTable.FreqTable(e_freq, FreqTable.FREQ,
                                    IUPAC.unambiguous_dna)
 
-print 'relative information:', align_info.information_content(
-                                   e_freq_table = e_freq_table,
-                                   chars_to_ignore = ['N'])
+print 'relative information: %0.2f' \
+      % align_info.information_content(e_freq_table = e_freq_table,
+                                       chars_to_ignore = ['N'])
 
 print 'Column 1:', align_info.get_column(1)
-print 'IC for column 1:', align_info.ic_vector[1]
+print 'IC for column 1: %0.2f' % align_info.ic_vector[1]
 print 'Column 7:', align_info.get_column(7)
-print 'IC for column 7:', align_info.ic_vector[7]
+print 'IC for column 7: %0.2f' % align_info.ic_vector[7]
 print 'test print_info_content'
 AlignInfo.print_info_content(align_info)
 print "testing reading and writing fasta format..."
 
 to_parse = os.path.join(os.curdir, 'Quality', 'example.fasta')
 
-alignment = AlignIO.read(open(to_parse), "fasta",
+alignment = AlignIO.read(to_parse, "fasta",
                          alphabet = Alphabet.Gapped(IUPAC.ambiguous_dna))
 
 # test the base alignment stuff
 print 'all_seqs...'
-all_seqs = alignment.get_all_seqs()
-for seq_record in all_seqs:
+for seq_record in alignment:
     print 'description:', seq_record.description
     print 'seq:', repr(seq_record.seq)
 
 print 'length:', alignment.get_alignment_length()
 align_info = AlignInfo.SummaryInfo(alignment)
 consensus = align_info.dumb_consensus(ambiguous="N", threshold=0.6)
-assert isinstance(consensus, Seq.Seq)
+assert isinstance(consensus, Seq)
 print 'consensus:', repr(consensus)
 
 print alignment
@@ -156,8 +154,8 @@ print alignment
 print "Test format conversion..."
 
 # parse the alignment file and get an aligment object
-alignment = Clustalw.parse_file(os.path.join(os.curdir, 'Clustalw',
-                                             'opuntia.aln'))
+alignment = AlignIO.read(os.path.join(os.curdir, 'Clustalw', 'opuntia.aln'),
+                         'clustal')
 
 print "As FASTA:"
 print alignment.format("fasta")
@@ -178,7 +176,7 @@ alignment = Alignment(gapped_unambiguous)
 for seq in alignment_info:
     alignment.add_sequence("Blah", seq)
 
-test_seq_1 = Seq.Seq("GATCCGATCG")
+test_seq_1 = Seq("GATCCGATCG")
 orig_pos = alignment.original_sequence_pos(3, test_seq_1, 0)
 assert orig_pos == 3, "Got unexpected position: %s" % orig_pos
 orig_pos = alignment.original_sequence_pos(7, test_seq_1, 0)
